@@ -2,7 +2,7 @@
 **  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009, 2010, 2012, 2013, The Trusted Domain Project.
+**  Copyright (c) 2009, 2010, 2012-2014, The Trusted Domain Project.
 **    All rights reserved.
 */
 
@@ -490,78 +490,3 @@ dkim_test_key(DKIM_LIB *lib, char *selector, char *domain,
 
 	return (status == 0 ? 0 : 1);
 }
-
-/*
-**  DKIM_TEST_ADSP -- verify that a valid author domain signing policy exists
-**                    in DNS
-**
-**  Parameters:
-**  	lib -- DKIM library handle
-**  	domain -- domain name
-**  	presult -- policy discovered (returned)
-**  	presult2 -- policy stage at which result was decided (returned)
-**  	err -- error buffer
-**  	errlen -- bytes available at "err"
-**
-**  Return value:
-**  	0 -- some kind of result was made available
-**  	-1 -- error
-*/
-
-int
-dkim_test_adsp(DKIM_LIB *lib, const char *domain, dkim_policy_t *presult,
-               int *presult2, char *err, size_t errlen)
-{
-	DKIM_STAT stat;
-	dkim_policy_t pcode = DKIM_POLICY_DEFAULT;
-	DKIM *dkim;
-
-	assert(lib != NULL);
-	assert(presult != NULL);
-	assert(presult2 != NULL);
-
-	dkim = dkim_verify(lib, (u_char *) "test", NULL, &stat);
-	if (dkim == NULL)
-	{
-		if (err != NULL)
-			strlcpy(err, dkim_getresultstr(stat), errlen);
-		return -1;
-	}
-
-	dkim->dkim_mode = DKIM_MODE_VERIFY;
-	dkim->dkim_domain = (u_char *) domain;
-	dkim->dkim_sigcount = 0;
-
-	stat = dkim_policy(dkim, &pcode, NULL, NULL);
-	if (stat != DKIM_STAT_OK)
-	{
-		if (err != NULL)
-		{
-			const char *errstr;
-
-			errstr = dkim_geterror(dkim);
-			if (errstr != NULL)
-			{
-				strlcpy(err, errstr, errlen);
-			}
-			else
-			{
-				strlcpy(err, dkim_getresultstr(stat),
-				        errlen);
-			}
-		}
-
-		dkim->dkim_domain = NULL;
-		(void) dkim_free(dkim);
-
-		return -1;
-	}
-
-	*presult = pcode;
-	*presult2 = dkim_getpresult(dkim);
-
-	dkim->dkim_domain = NULL;
-	(void) dkim_free(dkim);
-
-	return 0;
-}
