@@ -2,8 +2,7 @@
 **  Copyright (c) 2006-2009 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  Copyright (c) 2009-2013, The Trusted Domain Project.  All rights reserved.
-**
+**  Copyright (c) 2009-2014, The Trusted Domain Project.  All rights reserved.
 */
 
 #include "build-config.h"
@@ -233,10 +232,10 @@ config_load_level(char *file, struct configdef *def,
 		myline++;
 		str = NULL;
 
-		/* read a line; truncate at newline or "#" */
+		/* read a line; truncate at carriage return, newline, or "#" */
 		for (p = buf; *p != '\0'; p++)
 		{
-			if (*p == '#')
+			if (*p == '#' || *p == 0x0D)
 			{
 				*p = '\0';
 				break;
