@@ -24,9 +24,6 @@
 /* config definition */
 struct configdef dkimf_config[] =
 {
-	{ "AddAllSignatureResults",	CONFIG_TYPE_BOOLEAN,	FALSE },
-	{ "ADSPAction",			CONFIG_TYPE_STRING,	FALSE },
-	{ "ADSPNoSuchDomain",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "AllowSHA1Only",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "AlwaysAddARHeader",		CONFIG_TYPE_BOOLEAN,	FALSE },
 #ifdef _FFR_ATPS
@@ -43,7 +40,6 @@ struct configdef dkimf_config[] =
 	{ "BodyLengthDB",		CONFIG_TYPE_STRING,	FALSE },
 #ifdef USE_UNBOUND
 	{ "BogusKey",			CONFIG_TYPE_STRING,	FALSE },
-	{ "BogusPolicy",		CONFIG_TYPE_STRING,	FALSE },
 #endif /* USE_UNBOUND*/
 	{ "Canonicalization",		CONFIG_TYPE_STRING,	FALSE },
 	{ "CaptureUnknownErrors",	CONFIG_TYPE_BOOLEAN,	FALSE },
@@ -54,7 +50,6 @@ struct configdef dkimf_config[] =
 #endif /* _FFR_DEFAULT_SENDER */
 	{ "Diagnostics",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "DiagnosticDirectory",	CONFIG_TYPE_STRING,	FALSE },
-	{ "DisableADSP",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "DisableCryptoInit",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "DNSConnect",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "DNSTimeout",			CONFIG_TYPE_INTEGER,	FALSE },
@@ -77,6 +72,7 @@ struct configdef dkimf_config[] =
 	{ "IdentityHeader",		CONFIG_TYPE_STRING,     FALSE },
 	{ "IdentityHeaderRemove",	CONFIG_TYPE_BOOLEAN,    FALSE },
 #endif /* _FFR_IDENTITY_HEADER */
+	{ "IgnoreMalformedMail",	CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "Include",			CONFIG_TYPE_INCLUDE,	FALSE },
 	{ "InternalHosts",		CONFIG_TYPE_STRING,	FALSE },
 	{ "KeepAuthResults",		CONFIG_TYPE_BOOLEAN,	FALSE },
@@ -96,11 +92,9 @@ struct configdef dkimf_config[] =
 	{ "LDAPKeepaliveIdle",		CONFIG_TYPE_STRING,	FALSE },
 	{ "LDAPKeepaliveInterval",	CONFIG_TYPE_STRING,	FALSE },
 	{ "LDAPKeepaliveProbes",	CONFIG_TYPE_STRING,	FALSE },
-	{ "LDAPSoftStart",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "LDAPTimeout",		CONFIG_TYPE_STRING,	FALSE },
 	{ "LDAPUseTLS",			CONFIG_TYPE_BOOLEAN,	FALSE },
 #endif /* USE_LDAP */
-	{ "LocalADSP",			CONFIG_TYPE_STRING,	FALSE },
 	{ "LogResults",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "LogWhy",			CONFIG_TYPE_BOOLEAN,	FALSE },
 #ifdef _FFR_LUA_ONLY_SIGNING
@@ -119,9 +113,6 @@ struct configdef dkimf_config[] =
 	{ "MTACommand",			CONFIG_TYPE_STRING,	FALSE },
 	{ "MustBeSigned",		CONFIG_TYPE_STRING,	FALSE },
 	{ "Nameservers",		CONFIG_TYPE_STRING,	FALSE },
-#ifdef _FFR_ADSP_LISTS
-	{ "NoDiscardableMailTo",	CONFIG_TYPE_STRING,	FALSE },
-#endif /* _FFR_ADSP_LISTS */
 	{ "NoHeaderB",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "OmitHeaders",		CONFIG_TYPE_STRING,	FALSE },
 	{ "On-BadSignature",		CONFIG_TYPE_STRING,	FALSE },
@@ -130,7 +121,6 @@ struct configdef dkimf_config[] =
 	{ "On-InternalError",		CONFIG_TYPE_STRING,	FALSE },
 	{ "On-KeyNotFound",		CONFIG_TYPE_STRING,	FALSE },
 	{ "On-NoSignature",		CONFIG_TYPE_STRING,	FALSE },
-	{ "On-PolicyError",		CONFIG_TYPE_STRING,	FALSE },
 #ifdef _FFR_REPUTATION
 	{ "On-ReputationError",		CONFIG_TYPE_STRING,	FALSE },
 #endif /* _FFR_REPUTATION */
@@ -176,10 +166,10 @@ struct configdef dkimf_config[] =
 #endif /* _FFR_REPRRD */
 #ifdef _FFR_REPUTATION
 	{ "ReputationSpamCheck",	CONFIG_TYPE_STRING,	FALSE },
-	{ "ReputationTest",		CONFIG_TYPE_BOOLEAN,	FALSE },
+	{ "ReputationTest", /* DUP */	CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "ReputationTimeFactor",	CONFIG_TYPE_INTEGER,	FALSE },
 	{ "ReputationTimeout",		CONFIG_TYPE_INTEGER,	FALSE },
-	{ "ReputationVerbose",		CONFIG_TYPE_BOOLEAN,	FALSE },
+	{ "ReputationVerbose", /* DUP */ CONFIG_TYPE_BOOLEAN,	FALSE },
 #endif /* _FFR_REPUTATION */
 	{ "RequestReports",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "RequiredHeaders",		CONFIG_TYPE_BOOLEAN,	FALSE },
@@ -195,8 +185,6 @@ struct configdef dkimf_config[] =
 #endif /* USE_LUA */
 	{ "Selector",			CONFIG_TYPE_STRING,	FALSE },
 	{ "SelectCanonicalizationHeader", CONFIG_TYPE_STRING,	FALSE },
-	{ "SendADSPReports",		CONFIG_TYPE_BOOLEAN,	FALSE },
-	{ "SenderHeaders",		CONFIG_TYPE_STRING,	FALSE },
 #ifdef _FFR_SENDER_MACRO
 	{ "SenderMacro",		CONFIG_TYPE_STRING,	FALSE },
 #endif /* _FFR_SENDER_MACRO */
@@ -213,6 +201,9 @@ struct configdef dkimf_config[] =
 #endif /* HAVE_CURL_EASY_STRERROR */
 	{ "Socket",			CONFIG_TYPE_STRING,	FALSE },
 	{ "SoftwareHeader",		CONFIG_TYPE_BOOLEAN,	FALSE },
+#if defined(USE_ODBX) || defined(USE_LDAP)
+	{ "SoftStart",			CONFIG_TYPE_BOOLEAN,	FALSE },
+#endif /* defined(USE_ODBX) || defined(USE_LDAP) */
 #ifdef _FFR_STATS
 	{ "Statistics",			CONFIG_TYPE_STRING,	FALSE },
 	{ "StatisticsName",		CONFIG_TYPE_STRING,	FALSE },
@@ -237,7 +228,6 @@ struct configdef dkimf_config[] =
 	{ "UMask",			CONFIG_TYPE_INTEGER,	FALSE },
 #ifdef USE_UNBOUND
 	{ "UnprotectedKey",		CONFIG_TYPE_STRING,	FALSE },
-	{ "UnprotectedPolicy",		CONFIG_TYPE_STRING,	FALSE },
 #endif /* USE_UNBOUND */
 	{ "UserID",			CONFIG_TYPE_STRING,	FALSE },
 #ifdef _FFR_VBR
